@@ -343,7 +343,8 @@ def compare_source_lines(source_line_0, source_line_1, debug):
 
     # Some output for given sources can be ignored, e.g. output from timing
     # functions will not be exactly the same
-    ignore_output_if_source = ["timeit", "random_directions", "__version__"]
+    ignore_output_if_source = ["timeit", "random_directions", "__version__",
+                               "fact.time", "exec.time"]
     ignore_output_differences = False
 
     # Look at the source lines
